@@ -1,4 +1,4 @@
-# $Id: cmon.py 849 2014-02-05 00:38:55Z mwall $
+# $Id: cmon.py 929 2014-06-13 02:50:38Z mwall $
 # Copyright 2013 Matthew Wall
 """weewx module that records cpu, memory, disk, and network usage.
 
@@ -393,6 +393,11 @@ class ComputerMonitor(StdService):
                     self.last_net[iface] = {}
                 if self.last_net[iface].has_key(key):
                     record['net_'+iface+'_'+key] = int(values[i]) - self.last_net[iface][key]
+                    if record['net_'+iface+'_'+key] < 0:
+                        maxcnt = 0x100000000 # 32-bit counter
+                        if record['net_'+iface+'_'+key] + maxcnt < 0:
+                            maxcnt = 0x10000000000000000 # 64-bit counter
+                        record['net_'+iface+'_'+key] += maxcnt
                 self.last_net[iface][key] = int(values[i])
 
 #        uptimestr = _readproc_line('/proc/uptime')
